use chrono::{DateTime, Local};
use crate::common;
use crate::bar_modules;

#[derive(Clone)]
pub struct UnibarModuleDate {
    opts:       common::AppOptions,
    date_time:  DateTime<Local>,
}

impl UnibarModuleDate {
    // --------------------
    pub fn new(o :common::AppOptions) -> Self {
        UnibarModuleDate {
            opts:       o,
            date_time:  Local::now(),
        }
    }
}

impl bar_modules::BarModuleActions for UnibarModuleDate {

    // --------------------
    fn generate_data(&mut self) {
        self.date_time = Local::now();
        if self.opts.debug {
            println!("-----> Date dump {:#?}", self.date_time);
        }
    }

    // --------------------
    fn get_content(&self) -> String {
        return format!("{}", self.date_time.format("%Y %h %d"));
    }

    // --------------------
    fn get_icon(&self) -> String {
        return "📅".to_string();
    }
}

impl bar_modules::BarModuleDebug for UnibarModuleDate {

    // --------------------
    fn post_debug(&self) {
    }
}
